@@ -9,11 +9,11 @@
 #
 package Config::Model;
 BEGIN {
-  $Config::Model::VERSION = '1.235';
+  $Config::Model::VERSION = '1.236';
 }
-use Moose ;
-use Moose::Util::TypeConstraints;
-use MooseX::StrictConstructor ;
+use Any::Moose ;
+use Any::Moose '::Util::TypeConstraints';
+use Any::Moose 'X::StrictConstructor' ;
 
 use Carp;
 use Storable ('dclone') ;
@@ -21,6 +21,7 @@ use Data::Dumper ();
 use Log::Log4perl 1.11 qw(get_logger :levels);
 use Config::Model::Instance ;
 use Hash::Merge qw/merge/ ;
+use File::Path qw/make_path/;
 
 # this class holds the version number of the package
 use vars qw(@status @level @experience_list %experience_index
@@ -94,7 +95,7 @@ Config::Model - Create tools to validate, migrate and edit configuration files
 
 =head1 VERSION
 
-version 1.235
+version 1.236
 
 =head1 SYNOPSIS
 
@@ -783,9 +784,10 @@ L<Config::Model::Itself> model editor.
 =cut
 
 my @legal_params = qw/element experience status description summary level
-                      config_dir generated_by class_description
+                      config_dir
                       read_config read_config_dir write_config
                       write_config_dir accept/;
+my @static_legal_params = qw/class_description copyright author license generated_by/ ;                      
 
 sub create_config_class {
     my $self=shift ;
@@ -800,7 +802,7 @@ sub create_config_class {
         Config::Model::Exception::ModelDeclaration->throw
             (
              error=> "create_config_class: attempt to clobber $config_class_name".
-             "config class name "
+             " config class name "
             );
     }
 
@@ -868,7 +870,7 @@ sub _create_config_class {
         (
          error=> "create class $config_class_name: unknown ".
          "parameter '" . join("', '",@left_params)."', expected '".
-         join("', '",@legal_params,qw/class_description/)."'"
+         join("', '",@legal_params, @static_legal_params)."'"
         )
           if @left_params ;
 
@@ -932,7 +934,7 @@ sub check_class_parameters {
         # this parameter is filled by class generated by a program. It may
         # be used to avoid interactive edition of a generated model
         'generated_by',
-        'class_description',
+        qw/class_description author copyright license/
     ) ;
 
     foreach my $info (@info_to_move) {
@@ -1034,7 +1036,7 @@ sub check_class_parameters {
         (
          error => "create class $config_class_name: unexpected "
                 . "parameters '". join (', ', keys %$raw_model) ."' "
-                . "Expected '".join("', '",@legal_params)."'"
+                . "Expected '".join("', '",@legal_params, @static_legal_params)."'"
         )
           if keys %$raw_model ;
 
@@ -1662,7 +1664,7 @@ sub include_one_class {
                 $raw_model->{$included_item} = $to_copy ;
             }
         }
-        else {
+        elsif ( not grep { $_ eq $included_item; } @static_legal_params ) {
             Config::Model::Exception::ModelDeclaration->throw
                 (
                  error => "Cannot include '$included_item', "
@@ -1922,7 +1924,8 @@ sub augment_config_class {
 
 =head2 get_model( config_class_name )
 
-Return a hash containing the model declaration.
+Return a hash containing the model declaration (in a deep clone copy of the hash).
+You may modify the hash at leisure.
 
 =cut
 
@@ -1932,7 +1935,7 @@ sub get_model {
       || die "Model::get_model: missing config class name argument" ;
 
     $self->load($config_class_name)
-      unless defined $self->model($config_class_name) ;
+      unless $self->model_exists($config_class_name) ;
 
     my $model = $self->model($config_class_name) ||
       croak "get_model error: unknown config class name: $config_class_name";
@@ -1940,6 +1943,151 @@ sub get_model {
     return dclone($model) ;
 }
 
+=head2 get_model_doc 
+
+Generate POD document for configuration class.
+
+=cut
+
+sub get_model_doc {
+    my ( $self, $top_class_name ) = @_;
+
+    if ( not defined $self->model($top_class_name) ) {
+        croak
+          "get_model_doc error : unknown config class name: $top_class_name";
+    }
+
+    my @classes = ($top_class_name);
+    my %result;
+
+    while (@classes) {
+        my $class_name = shift @classes;
+        next if defined $result{$class_name};
+        my $c_model   = $self->get_model($class_name)
+          || croak "get_model_doc model error : unknown config class name: $class_name";
+
+        my $full_name = "Config::Model::models::$class_name" ;
+
+        my %see_also ;
+
+        my @pod = (
+            "=head1 NAME",                                    '',
+            "$full_name - Configuration class " . $class_name,                    '',
+            "=head1 DESCRIPTION",                             '',
+            "Configuration classes used by L<Config::Model>", ''
+        );
+
+        my %legalese;
+
+        my $i = 0;
+
+        my $class_desc = $c_model->{class_description};
+        push @pod, $class_desc, '' if defined $class_desc;
+
+        my @elt = ( "=head1 Elements", '' );
+        foreach my $elt_name ( @{ $c_model->{element_list} } ) {
+            my $elt_info = $c_model->{element}{$elt_name};
+            push @elt, "=head2 C<$elt_name>", '';
+            push @elt, $self->get_element_description($elt_info) , '' ;
+
+            foreach ($elt_info,$elt_info->{cargo}) { 
+                my $ccn = $_->{config_class_name};
+                next unless defined $ccn ;
+                push @classes, $ccn ;
+                $see_also{$ccn} = 1;
+            }
+        }
+
+        foreach my $what (qw/author copyright license/) {
+            my $item = $c_model->{$what};
+            push @{ $legalese{$what} }, $item if $item;
+        }
+
+        my @end;
+        foreach my $what (qw/author copyright license/) {
+            next unless @{ $legalese{$what} || [] };
+            push @end, "=head1 " . uc($what), '', '=over', '',
+              ( map { ( "=item $_", '' ); } @{ $legalese{$what} } ),
+              '', '=back', '';
+        }
+
+        my @see_also =  (
+            "=head1 SEE ALSO",'',"=over",'',"=item L<config-edit>",'',
+            ( map { ( "=item L<Config::Model::models::$_>",'') ; } sort keys %see_also ),
+            "=back",'') ;
+
+        $result{$full_name} = join( "\n", @pod, @elt, @see_also, @end,'=cut','' ) . "\n";
+    }
+    return \%result ;
+}
+
+sub get_element_description {
+    my ( $self, $elt_info ) = @_;
+
+    my $type  = $elt_info->{type};
+    my $cargo = $elt_info->{cargo};
+    my $vt    = $elt_info->{value_type} ;
+
+    my $of         = '';
+    my $cargo_type = $cargo->{type};
+    my $cargo_vt   = $cargo->{value_type};
+    $of = " of " . ( $cargo_vt or $cargo_type ) if defined $cargo_type;
+
+    my $desc = $elt_info->{description} || '';
+    $desc .= $elt_info->{mandatory} ? 'Mandatory' : 'Optional' ;
+    $desc .= ". Type ". ($vt || $type) . $of.'.';
+    foreach (qw/choice default upstream_default/) {
+        my $item = $elt_info->{$_} ;
+        next unless defined $item ;
+        my @list = ref($item) ? @$item : ($item) ;
+        $desc .= " $_: '". join("', '",@list)."'." ;
+    } 
+    return $desc ;
+}
+
+=head2 generate_doc ( top_class_name , [ directory ] )
+
+Generate POD document for configuration class top_class_name 
+and write them on STDOUT or in specified directory.
+
+Returns a list of written file names.
+
+=cut
+
+sub generate_doc {
+    my ( $self, $top_class_name, $dir ) = @_;
+
+    my $res  = $self->get_model_doc($top_class_name) ;
+    my @wrote ;
+
+    if (defined $dir and $dir) {
+        foreach my $class_name (keys %$res) {
+            my $file = $class_name;
+            $file =~ s!::!/!g ;
+            my $pl_file   = $self->model_dir."/$file.pl";
+            my $pod_file  = $dir."/$file.pod";
+            my $pod_dir = $pod_file ;
+            $pod_dir =~ s!/[^/]+$!!;
+            make_path($pod_dir,{ mode => 0755} ) unless -d $pod_dir ;
+            if (not -e $pod_file or not -e $pl_file or -M $pl_file > -M $pod_file ) {
+                my $fh = IO::File->new($pod_file,'>') || die "Can't open $pod_file: $!";
+                $fh->binmode(":utf8");
+                $fh->print($res->{$class_name});
+                $fh->close ;
+                print "Wrote documentation in $pod_file\n";
+                push @wrote, $pod_file ;
+            }
+        }
+    }
+    else {
+        foreach my $class_name (keys %$res) {
+            print "########## $class_name ############ \n\n";
+            print $res->{$class_name} ;
+        }
+    }
+    return @wrote ;
+}
+
 =head2 get_element_model( config_class_name , element)
 
 Return a hash containing the model declaration for the specified class
