@@ -27,10 +27,10 @@
 
 package Config::Model::Annotation;
 BEGIN {
-  $Config::Model::Annotation::VERSION = '1.235';
+  $Config::Model::Annotation::VERSION = '1.236';
 }
 
-use Moose ;
+use Any::Moose ;
 use English ;
 
 use File::Path;
@@ -57,7 +57,7 @@ Config::Model::Annotation - Read and write configuration annotations
 
 =head1 VERSION
 
-version 1.235
+version 1.236
 
 =head1 SYNOPSIS
 
