@@ -27,14 +27,14 @@
 
 package Config::Model::Backend::Any ;
 BEGIN {
-  $Config::Model::Backend::Any::VERSION = '1.235';
+  $Config::Model::Backend::Any::VERSION = '1.236';
 }
 
 use Carp;
 use strict;
 use warnings ;
 use Config::Model::Exception ;
-use Moose ;
+use Any::Moose ;
 
 use File::Path;
 use Log::Log4perl qw(get_logger :levels);
@@ -180,12 +180,12 @@ Config::Model::Backend::Any - Virtual class for other backends
 
 =head1 VERSION
 
-version 1.235
+version 1.236
 
 =head1 SYNOPSIS
 
  package Config::Model::Backend::Foo ;
- use Moose ;
+ use Any::Moose ;
  use Log::Log4perl qw(get_logger :levels);
 
  extends 'Config::Model::Backend::Any';
