@@ -9,10 +9,11 @@
 #
 package Config::Model::FuseUI ;
 BEGIN {
-  $Config::Model::FuseUI::VERSION = '1.235';
+  $Config::Model::FuseUI::VERSION = '1.236';
 }
 
-use Moose ;
+# there's no Singleton with Mouse
+use Any::Moose ;
 
 use Fuse qw(fuse_get_context);
 use Fcntl ':mode';
@@ -20,7 +21,6 @@ use POSIX qw(ENOENT EISDIR EINVAL);
 use Log::Log4perl qw(get_logger :levels);
 use English qw( -no_match_vars ) ;
 
-use MooseX::Singleton;
 has model         => ( is => 'rw', isa => 'Config::Model');
 has root          => ( is => 'ro', isa => 'Config::Model::Node', required => 1 );
 has mountpoint    => ( is => 'ro', isa => 'Str'          , required => 1 );
@@ -30,7 +30,10 @@ my $logger = get_logger("FuseUI") ;
 our $fuseui ;
 
 sub BUILD {
-    $fuseui = shift ; # store singleton object in global variable
+    my $self = shift ;
+    croak (__PACKAGE__," singleton constructed twice" )
+        if defined $fuseui and $fuseui ne $self;
+    $fuseui = $self ; # store singleton object in global variable
 }
 
 # nodes, list and hashes are directories
@@ -275,7 +278,7 @@ Config::Model::FuseUI - Fuse virtual file interface for Config::Model
 
 =head1 VERSION
 
-version 1.235
+version 1.236
 
 =head1 SYNOPSIS
 
