@@ -27,7 +27,7 @@
 
 package Config::Model::HashId ;
 BEGIN {
-  $Config::Model::HashId::VERSION = '1.235';
+  $Config::Model::HashId::VERSION = '1.236';
 }
 use Config::Model::Exception ;
 use Scalar::Util qw(weaken) ;
@@ -47,7 +47,7 @@ Config::Model::HashId - Handle hash element for configuration model
 
 =head1 VERSION
 
-version 1.235
+version 1.236
 
 =head1 SYNOPSIS
 
@@ -205,7 +205,13 @@ sub create_default {
     if (defined $self->{default_with_init}) {
         my $h = $self->{default_with_init} ;
         foreach my $def_key (keys %$h) {
-            $self->fetch_with_id($def_key)->load($h->{$def_key}) ;
+            my $v_obj = $self->fetch_with_id($def_key);
+            if ($v_obj->get_type eq 'leaf') {
+                $v_obj->store($h->{$def_key}) ;
+            }
+            else {
+                $v_obj->load($h->{$def_key}) ;
+            }
         }
     }
 }
